import 'package:flutter/services.dart';

extension StringExtension on String {
  /// Check email validation
  bool validateEmail() => RegExp(r"^[a-zA-Z0-9.a-zA-Z0-9.!#$%&'*+-/=?^_`{|}~]+@[a-zA-Z0-9]+\.[a-zA-Z]+").hasMatch(this);

  /// Check phone validation
  bool validatePhone() {
    return RegExp(r'(^(?:[+0]9)?[0-9]{10,12}$)').hasMatch(this);
  }

  /// Returns true if given String is null or isEmpty
  bool get isEmptyOrNull => this == null || isEmpty;

  String validate({String value = ''}) {
    if (this == null) {
      return value;
    } else {
      return this;
    }
  }

  /// Return true if given String is Digit
  bool isDigit(String s) {
    if (s.isEmpty) {
      return false;
    }
    if (s.length > 1) {
      for (var r in s.runes) {
        if (r ^ 0x30 > 9) {
          return false;
        }
      }
      return true;
    } else {
      return s.runes.first ^ 0x30 <= 9;
    }
  }

  /// Print given String
  log() {
    var dateTime = DateTime.now();
    print('${dateTime.hour}:${dateTime.minute}:${dateTime.second} $this');
  }

  /// Capitalize given String
  String capitalizeFirstLetter() {
    if (this.validate().length >= 1) {
      return (this.substring(0, 1).toUpperCase() + this.substring(1).toLowerCase());
    } else {
      return this.validate();
    }
  }

  // Copy String to Clipboard
  copyToClipboard() async {
    if (this == null || this.length <= 0) return;
    Clipboard.setData(ClipboardData(text: this));
  }
}
